sphinx_inline_tabs: Add inline tabbed content to your Sphinx documentation
==========================================================================

Description
-----------

Add inline tabbed content to your Sphinx documentation

License
-------

Upstream Contact
----------------

https://pypi.org/project/sphinx-inline-tabs/

